// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import "../imports/XAComponents"
import "../Map"

Item {
    id: maincomponent
    height: 49
    width: parent.width

    property string itemTitle: "<untitled>"
    property bool itemCompleted: false
    property bool itemFlagged: false

    property bool isEditable: false

    property bool isEditing: false
    property bool isModified: false
    property bool isSelected: false

    signal completedTriggered();
    signal flaggedTriggered();
    signal titleUpdated(string title);

    property Gradient backgroundGradient: Gradient {
//        GradientStop { position: 0.0; color: "white" }
//        GradientStop { position: 1.0; color: "#d9d9d9" }
        GradientStop { position: 0.0; color: "white" }
        GradientStop { position: 0.05; color: "#f2f2f2" }
        GradientStop { position: 1.0; color: "#f2f2f2" }
//        GradientStop { position: 1.0; color: "white" }
    }

    function edit()
    {
        itemTitleInput.activateControl(true)
    }

    function deactivateEdit() {
        itemTitleInput.deactivateEdit()
    }

    Rectangle {
        id: background
        anchors.fill: parent
        gradient: backgroundGradient

        Image {
            id: itemCompletedImage
            source: {
                if (maincomponent.itemCompleted) return "qrc:/icons/ActionCheckboxMediumPadOn.png"
                else return "qrc:/icons/ActionCheckboxMediumPadOff.png"
            }
            smooth: true

            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            anchors.leftMargin: 12

            MouseArea {
                id: itemCompletedMouseArea
                anchors.fill: parent
                acceptedButtons: Qt.LeftButton

                onPressed: {
                    console.debug("ItemViewBasic onPressed itemCompletedMouseArea")

                    maincomponent.itemCompleted = !maincomponent.itemCompleted
                    maincomponent.completedTriggered();
                }
            }
        }

        ItemViewTextInput {
            id: itemTitleInput

            property string defaultText: ""

            visible: true
            enabled: true
            editable: maincomponent.isEditable
            text: maincomponent.itemTitle

            anchors.top: parent.top
            //anchors.topMargin: 0
            anchors.topMargin: 10
            anchors.left: itemCompletedImage.right
            anchors.leftMargin: 44;
            anchors.right: parent.right
            anchors.rightMargin: 46
            anchors.bottom: parent.bottom
            //anchors.bottomMargin: 1
            anchors.bottomMargin: 11

            font.pixelSize: 15
            font.family: "Helvetica"
            font.bold: true

            smooth: true
            textColor: "black";
            activatedColor: "white";
            deactivatedColor: "transparent";
            clip: true

            onTextChanged: {
                titleUpdated(text);
                maincomponent.isModified = true;
            }

            onEscapePressed: {
                text = defaultText
                deactivateControl()
            }

            onReturnPressed: {
                console.debug("Return pressed with " + defaultText)
                if (defaultText !== text) {
                    titleUpdated(text);
                }

                deactivateControl()
                maincomponent.isEditing = false
            }

            onFocusLost: {
                console.debug("Focus Lost with " + defaultText)
                if (defaultText !== text) {
                    titleUpdated(text);
                }

                deactivateControl()

                maincomponent.isEditing = false
            }

            onSelectReceived: {
                console.debug("Select Received with " + defaultText)
                if (!maincomponent.isSelected) {
                    maincomponent.isSelected = true;
                } else {
                    activateControl()
                }

//                QtHandler.selectionChanged(itemView.itemType, itemView.itemUID, true);
            }

            onFocusReceived: {
                console.debug("Focus Received with " + defaultText)
                maincomponent.isSelected = true;
//                QtHandler.selectionChanged(itemView.itemType, itemView.itemUID, true);
                activateControl(true)

                maincomponent.isEditing = true
            }

        }

        Image {
            id: itemFlaggedImage
            source: {
                if (maincomponent.itemFlagged) return "qrc:/icons/ActionFlagOn.png"
                else return "qrc:/icons/ActionFlagOff.png"
            }
            smooth: true

            anchors.top: parent.top
            anchors.topMargin: -1
            anchors.right: parent.right
            anchors.rightMargin: 12

            MouseArea {
                id: itemFlaggedMouseArea
                anchors.fill: parent
                acceptedButtons: Qt.LeftButton

                onPressed: {
                    console.debug("ItemViewBasic onPressed itemFlaggedMouseArea")
                    maincomponent.itemFlagged = !maincomponent.itemFlagged
                    maincomponent.flaggedTriggered();
                }
            }
        }

    }


}
